from alvin_integration.installer.base import AlvinBaseInstaller
from alvin_integration.producers.airflow.config import AirflowProducerConfig


class AlvinAirflowInstaller(AlvinBaseInstaller):

    def __init__(self, *args, **kwargs):
        super(AlvinAirflowInstaller, self).__init__(provider_config=AirflowProducerConfig(), *args, **kwargs)



import os
import sys
from airflow import settings

import inspect


def create_alvin_dag_current():
    from alvin_integration.producers.airflow.pipeline import dag_metadata_current
    create_alvin_dag('alvin_metadata_dag.py', dag_metadata_current)


def create_alvin_dag_legacy():
    from alvin_integration.producers.airflow.pipeline import dag_metadata_legacy
    create_alvin_dag('alvin_metadata_dag.py', dag_metadata_legacy)


def create_alvin_dag(file_name, dag_module):

    print('Creating Alvin DAGs.....')
    dag_folder = settings.DAGS_FOLDER
    dag_source_code = inspect.getsource(sys.modules[dag_module.__name__])
    with open(os.path.join(dag_folder, file_name), 'w') as file:
        file.write(dag_source_code)


def create_alvin_dag_google_composer():
    print(f'Importing dag metadata dependencies.....')
    from alvin_integration.producers.airflow.pipeline import dag_metadata_current
    from alvin_integration.producers.airflow.config import GOOGLE_COMPOSER_BUCKET
    from google.cloud import storage

    print(f'Creating Alvin DAGs on Google Composer path {GOOGLE_COMPOSER_BUCKET}.....')

    dag_source_code = inspect.getsource(sys.modules[dag_metadata_current.__name__])

    client = storage.Client()

    bucket = client.get_bucket(GOOGLE_COMPOSER_BUCKET)

    blob = bucket.blob('dags/alvin_metadata_dag.py')

    blob.upload_from_string(dag_source_code)



from airflow.models import DAG
from airflow.operators.python_operator import PythonOperator
from datetime import datetime, timedelta
from airflow.utils import db
from alvin_integration.producers.airflow.pipeline.extractor import extract_dag_metadata

seven_days_ago = datetime.combine(
    datetime.today() - timedelta(1), datetime.min.time()
)  # noqa

args = {
    "owner": "airflow",
    "start_date": seven_days_ago,
}


@db.provide_session
def extract_metadata(session, **kwargs):
    """Extract metadata from DAG and send to Alvin Backend API."""
    extract_dag_metadata(session)


alvin_metadata_extractor = DAG(
    dag_id="alvin_metadata_extractor", default_args=args, schedule_interval="@hourly", catchup=False
)  # noqa

task_success_one = PythonOperator(
    task_id="dag_metadata_extractor",
    provide_context=True,
    python_callable=extract_metadata,
    dag=alvin_metadata_extractor,
)



import setuptools

requirements = [
    "gorilla==0.4.0",
    "openlineage-airflow==0.6.1"
]

setuptools.setup(
    name="alvin_integration_beta",
    version="0.0.6",
    author="Alvin",
    author_email="tech@alvin.ai",
    description="Alvin lineage python library for integrations",
    packages=setuptools.find_packages(),
    install_requires=requirements,
    python_requires=">=3.7",
)
